==> igniteui-webcomponents-core-3.2.0.tgz: package/esm5/lib/GridFilterDialogOpeningEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnDescriptionMetadata } from "./ColumnDescriptionMetadata";
import { GridFilterDialogOpeningEventArgsDescription } from "./GridFilterDialogOpeningEventArgsDescription";
/**
 * @hidden
 */
var GridFilterDialogOpeningEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridFilterDialogOpeningEventArgsDescriptionMetadata, _super);
    function GridFilterDialogOpeningEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridFilterDialogOpeningEventArgsDescriptionMetadata.b = function (a) {
        if (GridFilterDialogOpeningEventArgsDescriptionMetadata.a == null) {
            GridFilterDialogOpeningEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridFilterDialogOpeningEventArgsDescriptionMetadata.c(GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
        }
        if (a.g(GridFilterDialogOpeningEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
        ColumnDescriptionMetadata.d(a);
    };
    GridFilterDialogOpeningEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:Column");
    };
    GridFilterDialogOpeningEventArgsDescriptionMetadata.d = function (a) {
        GridFilterDialogOpeningEventArgsDescriptionMetadata.b(a);
        a.u("GridFilterDialogOpeningEventArgs", function () { return new GridFilterDialogOpeningEventArgsDescription(); });
        a.t("GridFilterDialogOpeningEventArgs", GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
    };
    GridFilterDialogOpeningEventArgsDescriptionMetadata.$t = markType(GridFilterDialogOpeningEventArgsDescriptionMetadata, 'GridFilterDialogOpeningEventArgsDescriptionMetadata');
    GridFilterDialogOpeningEventArgsDescriptionMetadata.a = null;
    return GridFilterDialogOpeningEventArgsDescriptionMetadata;
}(Base));
export { GridFilterDialogOpeningEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/GridFilterDialogOpeningEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridFilterDialogOpeningEventArgsDescription } from "./GridFilterDialogOpeningEventArgsDescription";
/**
 * @hidden
 */
var GridFilterDialogOpeningEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(GridFilterDialogOpeningEventArgsDescriptionMetadata, _super);
    function GridFilterDialogOpeningEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridFilterDialogOpeningEventArgsDescriptionMetadata.b = function (a) {
        if (GridFilterDialogOpeningEventArgsDescriptionMetadata.a == null) {
            GridFilterDialogOpeningEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridFilterDialogOpeningEventArgsDescriptionMetadata.c(GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
        }
        if (a.j(GridFilterDialogOpeningEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
        DataGridColumnDescriptionMetadata.d(a);
    };
    GridFilterDialogOpeningEventArgsDescriptionMetadata.c = function (a) {
        a.item("Column", "ExportedType:DataGridColumn");
    };
    GridFilterDialogOpeningEventArgsDescriptionMetadata.d = function (a) {
        GridFilterDialogOpeningEventArgsDescriptionMetadata.b(a);
        a.aa("GridFilterDialogOpeningEventArgs", function () { return new GridFilterDialogOpeningEventArgsDescription(); });
        a.z("GridFilterDialogOpeningEventArgs", GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
    };
    GridFilterDialogOpeningEventArgsDescriptionMetadata.$t = markType(GridFilterDialogOpeningEventArgsDescriptionMetadata, 'GridFilterDialogOpeningEventArgsDescriptionMetadata');
    GridFilterDialogOpeningEventArgsDescriptionMetadata.a = null;
    return GridFilterDialogOpeningEventArgsDescriptionMetadata;
}(Base));
export { GridFilterDialogOpeningEventArgsDescriptionMetadata };
